==> ej2-vue-maps-19.3.43.tgz: package/src/maps/initialshapeselection.directive.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { EJComponentDecorator, allVue, gh } from '@syncfusion/ej2-vue-base';
import * as Vue3 from 'vue-class-component';
import Vue from 'vue';
export var isExecute = gh ? false : true;
var vueImport;
if (!isExecute || parseInt(allVue.version) < 3) {
    vueImport = Vue3.Vue;
}
else {
    vueImport = Vue;
}
var InitialShapeSelectionsDirective = /** @class */ (function (_super) {
    __extends(InitialShapeSelectionsDirective, _super);
    function InitialShapeSelectionsDirective() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    InitialShapeSelectionsDirective.prototype.render = function () {
        return;
    };
    InitialShapeSelectionsDirective.prototype.getTag = function () {
        return 'e-initialShapeSelections';
    };
    InitialShapeSelectionsDirective = __decorate([
        EJComponentDecorator({}, isExecute)
    ], InitialShapeSelectionsDirective);
    return InitialShapeSelectionsDirective;
}(vueImport));
export { InitialShapeSelectionsDirective };
export var InitialShapeSelectionsPlugin = {
    name: 'e-initialShapeSelections',
    install: function (Vue) {
        Vue.component(InitialShapeSelectionsPlugin.name, InitialShapeSelectionsDirective);
    }
};
/**
 * `InitialShapeSelectionsDirective` directive represent a selection settings of the Vuejs maps.
 * ```vue
 * <ejs-maps>
 * <e-layers>
 * <e-layer>
 * <e-initialShapeSelections>
 * <e-initialShapeSelection>
 * </e-initialShapeSelection>
 * </e-initialShapeSelections>
 * </e-layer>
 * </e-layers>
 * </ejs-maps>
 * ```
 */
var InitialShapeSelectionDirective = /** @class */ (function (_super) {
    __extends(InitialShapeSelectionDirective, _super);
    function InitialShapeSelectionDirective() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    InitialShapeSelectionDirective.prototype.render = function () {
        return;
    };
    InitialShapeSelectionDirective.prototype.getTag = function () {
        return 'e-initialShapeSelection';
    };
    InitialShapeSelectionDirective = __decorate([
        EJComponentDecorator({}, isExecute)
    ], InitialShapeSelectionDirective);
    return InitialShapeSelectionDirective;
}(vueImport));
export { InitialShapeSelectionDirective };
export var InitialShapeSelectionPlugin = {
    name: 'e-initialShapeSelection',
    install: function (Vue) {
        Vue.component(InitialShapeSelectionPlugin.name, InitialShapeSelectionDirective);
    }
};

==> ej2-vue-maps-20.2.38.tgz: package/src/maps/initialshapeselection.directive.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { EJComponentDecorator, allVue, gh } from '@syncfusion/ej2-vue-base';
import * as Vue3 from 'vue-class-component';
import { isNullOrUndefined } from '@syncfusion/ej2-base';
import Vue from 'vue';
import { Options } from 'vue-class-component';
export var isExecute = gh ? false : true;
var vueImport;
if (!isExecute || parseInt(allVue.version) < 3) {
    vueImport = Vue3.Vue;
}
else {
    vueImport = Vue;
}
var InitialShapeSelectionsDirective = /** @class */ (function (_super) {
    __extends(InitialShapeSelectionsDirective, _super);
    function InitialShapeSelectionsDirective() {
        return _super.call(this, arguments) || this;
    }
    InitialShapeSelectionsDirective.prototype.render = function (createElement) {
        if (gh) {
            var h = gh || createElement;
            var slots = null;
            if (!isNullOrUndefined(this.$slots.default)) {
                slots = gh ? this.$slots.default() : this.$slots.default;
            }
            return h('div', { class: 'e-directive' }, slots);
        }
        return;
    };
    InitialShapeSelectionsDirective.prototype.updated = function () {
        if (gh && this.custom) {
            this.custom();
        }
    };
    InitialShapeSelectionsDirective.prototype.getTag = function () {
        return 'e-initialShapeSelections';
    };
    InitialShapeSelectionsDirective = __decorate([
        EJComponentDecorator({}, isExecute)
        ,Options({
            inject: {
                custom: {
                    default: null
                }
            }
        })
    ], InitialShapeSelectionsDirective);
    return InitialShapeSelectionsDirective;
}(vueImport));
export { InitialShapeSelectionsDirective };
export var InitialShapeSelectionsPlugin = {
    name: 'e-initialShapeSelections',
    install: function (Vue) {
        Vue.component(InitialShapeSelectionsPlugin.name, InitialShapeSelectionsDirective);
    }
};
/**
 * `InitialShapeSelectionsDirective` directive represent a selection settings of the Vuejs maps.
 * ```vue
 * <ejs-maps>
 * <e-layers>
 * <e-layer>
 * <e-initialShapeSelections>
 * <e-initialShapeSelection>
 * </e-initialShapeSelection>
 * </e-initialShapeSelections>
 * </e-layer>
 * </e-layers>
 * </ejs-maps>
 * ```
 */
var InitialShapeSelectionDirective = /** @class */ (function (_super) {
    __extends(InitialShapeSelectionDirective, _super);
    function InitialShapeSelectionDirective() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    InitialShapeSelectionDirective.prototype.render = function () {
        return;
    };
    InitialShapeSelectionDirective.prototype.getTag = function () {
        return 'e-initialShapeSelection';
    };
    InitialShapeSelectionDirective = __decorate([
        EJComponentDecorator({}, isExecute)
    ], InitialShapeSelectionDirective);
    return InitialShapeSelectionDirective;
}(vueImport));
export { InitialShapeSelectionDirective };
export var InitialShapeSelectionPlugin = {
    name: 'e-initialShapeSelection',
    install: function (Vue) {
        Vue.component(InitialShapeSelectionPlugin.name, InitialShapeSelectionDirective);
    }
};
